@@ -1,23 +1,21 @@
 #' PPC intervals
 #'
-#' Medians and central interval estimates of \code{yrep} with \code{y} overlaid.
-#' See the \strong{Plot Descriptions} section, below.
+#' Medians and central interval estimates of `yrep` with `y` overlaid.
+#' See the **Plot Descriptions** section, below.
 #'
 #' @name PPC-intervals
 #' @family PPCs
 #'
 #' @template args-y-yrep
-#' @param x A numeric vector the same length as \code{y} to use as the x-axis
-#'   variable. For example, \code{x} could be a predictor variable from a
-#'   regression model, a time variable for time-series models, etc. If \code{x}
-#'   is missing or NULL, then \code{1:length(y)} is used for the x-axis.
+#' @template args-prob-prob_outer
+#' @param x A numeric vector the same length as `y` to use as the x-axis
+#'   variable. For example, `x` could be a predictor variable from a
+#'   regression model, a time variable for time-series models, etc. If `x`
+#'   is missing or `NULL`, then `1:length(y)` is used for the x-axis.
 #' @param ... Currently unused.
-#' @param prob A value between 0 and 1 indicating the desired probability mass
-#'   to include in the \code{yrep} intervals. The default is 0.9.
-#' @param alpha,size,fatten Arguments passed to geoms. For ribbon plots
-#'   \code{alpha} and \code{size} are passed to
-#'   \code{\link[ggplot2]{geom_ribbon}}. For interval plots \code{size} and
-#'   \code{fatten} are passed to \code{\link[ggplot2]{geom_pointrange}}.
+#' @param alpha,size,fatten Arguments passed to geoms. For ribbon plots `alpha`
+#'   and `size` are passed to [ggplot2::geom_ribbon()]. For interval plots
+#'   `size` and `fatten` are passed to [ggplot2::geom_pointrange()].
 #'
 #' @template return-ggplot-or-data
 #'
@@ -26,21 +24,21 @@
 #'
 #' @section Plot Descriptions:
 #' \describe{
-#'   \item{\code{ppc_intervals, ppc_ribbon}}{
-#'    \code{100*prob}\% central intervals for \code{yrep} at each \code{x}
-#'    value. \code{ppc_intervals} plots intervals as vertical bars with points
-#'    indicating \code{yrep} medians and darker points indicating observed
-#'    \code{y} values. \code{ppc_ribbon} plots a ribbon of connected intervals
-#'    with a line through the median of \code{yrep} and a darker line connecting
-#'    observed \code{y} values. In both cases an optional \code{x} variable can
+#'   \item{`ppc_intervals(), ppc_ribbon()`}{
+#'    `100*prob`\% central intervals for `yrep` at each `x`
+#'    value. `ppc_intervals()` plots intervals as vertical bars with points
+#'    indicating `yrep` medians and darker points indicating observed
+#'    `y` values. `ppc_ribbon()` plots a ribbon of connected intervals
+#'    with a line through the median of `yrep` and a darker line connecting
+#'    observed `y` values. In both cases an optional `x` variable can
 #'    also be specified for the x-axis variable.
 #'
 #'    Depending on the number of observations and the variability in the
-#'    predictions at different values of \code{x}, one or the other of these
+#'    predictions at different values of `x`, one or the other of these
 #'    plots may be easier to read than the other.
 #'   }
-#'   \item{\code{ppc_intervals_grouped, ppc_ribbon_grouped}}{
-#'    Same as \code{ppc_intervals} and \code{ppc_ribbon}, respectively, but a
+#'   \item{`ppc_intervals_grouped(), ppc_ribbon_grouped()`}{
+#'    Same as `ppc_intervals()` and `ppc_ribbon()`, respectively, but a
 #'    separate plot (facet) is generated for each level of a grouping variable.
 #'   }
 #' }
@@ -55,7 +53,7 @@
 #'
 #' # change x axis to y values (instead of indices) and add x = y line
 #' ppc_intervals(y, yrep, x = y) + abline_01()
-#' 
+#'
 #'
 #' color_scheme_set("teal")
 #' year <- 1950:1999
@@ -77,12 +75,12 @@
 #'  xaxis_ticks(FALSE) +
 #'  panel_bg(fill = "gray20")
 #'
-#' ppc_data <- ppc_intervals_data(y, yrep, x = year, prob = 0.5)
-#' ppc_group_data <- ppc_intervals_data(y, yrep, x = year, group, prob = 0.5)
+#' ppc_dat <- ppc_intervals_data(y, yrep, x = year, prob = 0.5)
+#' ppc_group_dat <- ppc_intervals_data(y, yrep, x = year, group = group, prob = 0.5)
 #'
 #' \dontrun{
 #' library("rstanarm")
-#' fit <- stan_glmer(mpg ~ wt + (1|cyl), data = mtcars)
+#' fit <- stan_glmer(mpg ~ wt + (1|cyl), data = mtcars, refresh = 0)
 #' yrep <- posterior_predict(fit)
 #'
 #' color_scheme_set("purple")
@@ -109,8 +107,8 @@ NULL
 
 #' @rdname PPC-intervals
 #' @export
-ppc_intervals <- function(y, yrep, x = NULL, ..., prob = 0.9, size = 1,
-                          fatten = 3) {
+ppc_intervals <- function(y, yrep, x = NULL, ..., prob = 0.5, prob_outer = 0.9,
+                          size = 1, fatten = 3) {
   check_ignored_arguments(...)
 
   data <- ppc_intervals_data(
@@ -118,7 +116,8 @@ ppc_intervals <- function(y, yrep, x = NULL, ..., prob = 0.9, size = 1,
       yrep = yrep,
       x = x,
       group = NULL,
-      prob = prob
+      prob = prob,
+      prob_outer = prob_outer
   )
 
   .ppc_intervals(
@@ -134,32 +133,32 @@ ppc_intervals <- function(y, yrep, x = NULL, ..., prob = 0.9, size = 1,
 #' @rdname PPC-intervals
 #' @export
 #' @template args-group
-#' @param facet_args An optional list of  arguments (other than \code{facets})
-#'   passed to \code{\link[ggplot2]{facet_wrap}} to control faceting.
+#' @param facet_args An optional list of  arguments (other than `facets`)
+#'   passed to [ggplot2::facet_wrap()] to control faceting.
 #'
 ppc_intervals_grouped <- function(y,
                                   yrep,
                                   x = NULL,
                                   group,
-                                  facet_args = list(),
                                   ...,
-                                  prob = 0.9,
+                                  facet_args = list(),
+                                  prob = 0.5,
+                                  prob_outer = 0.9,
                                   size = 1,
                                   fatten = 3) {
   check_ignored_arguments(...)
 
-  if (is.null(facet_args[["scales"]])) {
-    facet_args[["scales"]] <- "free"
-  }
-
   data <- ppc_intervals_data(
     y = y,
     yrep = yrep,
     x = x,
     group = group,
-    prob = prob
+    prob = prob,
+    prob_outer = prob_outer
   )
 
+  facet_args[["scales"]] <- facet_args[["scales"]] %||% "free"
+
   .ppc_intervals(
     data = data,
     facet_args = facet_args,
@@ -178,7 +177,8 @@ ppc_ribbon <- function(y,
                        yrep,
                        x = NULL,
                        ...,
-                       prob = 0.9,
+                       prob = 0.5,
+                       prob_outer = 0.9,
                        alpha = 0.33,
                        size = 0.25) {
   check_ignored_arguments(...)
@@ -208,25 +208,25 @@ ppc_ribbon_grouped <- function(y,
                                yrep,
                                x = NULL,
                                group,
-                               facet_args = list(),
                                ...,
-                               prob = 0.9,
+                               facet_args = list(),
+                               prob = 0.5,
+                               prob_outer = 0.9,
                                alpha = 0.33,
                                size = 0.25) {
   check_ignored_arguments(...)
 
-  if (is.null(facet_args[["scales"]])) {
-    facet_args[["scales"]] <- "free"
-  }
-
   data <- ppc_intervals_data(
     y = y,
     yrep = yrep,
     x = x,
     group = group,
-    prob = prob
+    prob = prob,
+    prob_outer = prob_outer
   )
 
+  facet_args[["scales"]] <- facet_args[["scales"]] %||% "free"
+
   .ppc_intervals(
     data = data,
     facet_args = facet_args,
@@ -241,9 +241,11 @@ ppc_ribbon_grouped <- function(y,
 
 #' @rdname PPC-intervals
 #' @export
-ppc_intervals_data <- function(y, yrep, x = NULL, group = NULL, prob = 0.9, ...) {
+ppc_intervals_data <- function(y, yrep, x = NULL, group = NULL,
+                               ..., prob = 0.5, prob_outer = 0.9) {
   check_ignored_arguments(...)
-  .ppc_intervals_data(y = y, yrep = yrep, x = x, group = group, prob = prob)
+  .ppc_intervals_data(y = y, yrep = yrep, x = x, group = group,
+                      prob = prob, prob_outer = prob_outer)
 }
 
 
@@ -259,9 +261,14 @@ label_x <- function(x) {
   if (missing(x)) "Index" else NULL
 }
 
-.ppc_intervals_data <- function(y, yrep, x = NULL, group = NULL, prob = 0.8) {
+.ppc_intervals_data <- function(y, yrep, x = NULL, group = NULL,
+                                prob = 0.5, prob_outer = 0.9) {
   grouped <- !is.null(group)
   stopifnot(prob > 0 && prob < 1)
+  stopifnot(prob_outer > 0 && prob_outer <= 1)
+  probs <- sort(c(prob, prob_outer))
+  prob <- probs[1]
+  prob_outer <- probs[2]
 
   y <- validate_y(y)
   yrep <- validate_yrep(yrep, y)
@@ -283,16 +290,19 @@ label_x <- function(x) {
   }
 
   grouped_d <- dplyr::group_by(molten_reps, !!! group_vars)
-  alpha <- (1 - prob) / 2
+  alpha <- (1 - probs) / 2
   probs <- sort(c(alpha, 0.5, 1 - alpha))
 
   val_col <- sym("value")
   dplyr::ungroup(dplyr::summarise(
     grouped_d,
-    prob = prob,
-    lo = quantile(!! val_col, prob = probs[1]),
-    mid = quantile(!! val_col, prob = probs[2]),
-    hi = quantile(!! val_col, prob = probs[3])
+    outer_width = prob_outer,
+    inner_width = prob,
+    ll = quantile(!! val_col, prob = probs[1]),
+    l  = quantile(!! val_col, prob = probs[2]),
+    m  = quantile(!! val_col, prob = probs[3]),
+    h  = quantile(!! val_col, prob = probs[4]),
+    hh = quantile(!! val_col, prob = probs[5])
   ))
 }
 
@@ -317,14 +327,19 @@ label_x <- function(x) {
     data = data,
     mapping = aes_(
       x = ~ x,
-      y = ~ mid,
-      ymin = ~ lo,
-      ymax = ~ hi
+      y = ~ m,
+      ymin = ~ l,
+      ymax = ~ h
     )
   )
 
   if (style == "ribbon") {
     graph <- graph +
+      geom_ribbon(
+        aes_(color = "yrep", fill = "yrep", ymin = ~ ll, ymax = ~ hh),
+        alpha = alpha,
+        size = size
+      ) +
       geom_ribbon(
         aes_(color = "yrep", fill = "yrep"),
         alpha = alpha,
@@ -341,6 +356,13 @@ label_x <- function(x) {
       )
   } else {
     graph <- graph +
+      geom_pointrange(
+        mapping = aes_(color = "yrep", fill = "yrep", ymin = ~ ll, ymax = ~ hh),
+        shape = 21,
+        alpha = alpha,
+        size = size,
+        fatten = fatten
+      ) +
       geom_pointrange(
         mapping = aes_(color = "yrep", fill = "yrep"),
         shape = 21,
@@ -357,7 +379,7 @@ label_x <- function(x) {
   graph <- graph +
     scale_color_manual(
       name = "",
-      values = setNames(get_color(c("lh", "dh")), c("yrep", "y")),
+      values = set_names(get_color(c("lh", "dh")), c("yrep", "y")),
       labels = c(yrep = yrep_label(), y = y_label())
     ) +
     scale_fill_manual(
@@ -370,13 +392,12 @@ label_x <- function(x) {
 
   if (grouped) {
     facet_args[["facets"]] <- "group"
-    if (is.null(facet_args[["scales"]])) {
-      facet_args[["scales"]] <- "free"
-    }
+    facet_args[["scales"]] <- facet_args[["scales"]] %||% "free"
     graph <- graph + do.call("facet_wrap", facet_args)
   }
 
   graph +
-    labs(y = NULL, x = x_lab %||% expression(italic(x)))
+    labs(y = NULL, x = x_lab %||% expression(italic(x))) +
+    bayesplot_theme_get()
 }
 
